@@ -481,7 +481,7 @@ class EmergePackage(Mapping):
     pr = r"(?:-(r\d+))?"
     tbz = r"(?:.(tbz2))?"
     slot = r'(?::([^:/]+(?:/[^:/]+)?))?'
-    repo = r'(?:::(\w+))?'
+    repo = r'(?:::([\w-]+))?'
 
     reParse = re.compile(
         r'^{prefix}{category}(({pn}{pv}){pr}){slot}{repo}{tbz}$'.format(
